API docs for “spamfighter.core.commands.test.test_apiglue.XML_RPCTestCase”

# Class s.c.c.t.t.XML_RPCTestCase(unittest.TestCase):

Part of spamfighter.core.commands.test.test_apiglue View Source View In Hierarchy

Тест на `spamfighter.core.commands.apiglue.XMLRPC_API_Glue`.

Method | testErrorTranslator | Undocumented
Method | testDeferredErrorTranslator1 | Undocumented
Method | testDeferredErrorTranslator2 | Undocumented
Method | testDeferredErrorTranslator3 | Undocumented
Method | testGetFunction | Undocumented
Method | testGetFunctionNoSuchParam | Undocumented
Method | testGetFunctionUnknownType | Undocumented
Method | testGetFunctionNoSuchFunction | Undocumented

def testErrorTranslator(self): (source)
Undocumented
def testDeferredErrorTranslator1(self): (source)
Undocumented
def testDeferredErrorTranslator2(self): (source)
Undocumented
def testDeferredErrorTranslator3(self): (source)
Undocumented
def testGetFunction(self): (source)
Undocumented
def testGetFunctionNoSuchParam(self): (source)
Undocumented
def testGetFunctionUnknownType(self): (source)
Undocumented
def testGetFunctionNoSuchFunction(self): (source)
Undocumented